View — Pyramid Class-Based Views 1.0 documentation

# View

class `pyramid_views.views.base.` `View`(**kwargs)

  Intentionally simple parent class for all views. Only implements dispatch-by-method and simple sanity checking.

  `get`(self, request, *args, **kwargs)
  `post`(self, request, *args, **kwargs)
  `put`(self, request, *args, **kwargs)
  `delete`(self, request, *args, **kwargs)
  classmethod `as_view`(**initkwargs)

    Main entry point for a request-response process.

  `dispatch`(request, *args, **kwargs)
  `http_method_not_allowed`(request, *args, **kwargs)
  `options`(request, *args, **kwargs)

    Handles responding to requests for the OPTIONS HTTP verb.

  `http_method_names` = [u'get', u'post', u'put', u'patch', u'delete', u'head', u'options', u'trace']